@@ -101,9 +101,13 @@ class Drive(NetBoxModel):
     def partition_count(self):
         return Partition.objects.filter(drive=self).count()
 
+    @property
     def free_space_on_drive(self):
-        print(f"Free Space: {Partition.objects.filter(drive=self).aggregate(Sum('size'))['size__sum']}")
-        return self.size - Partition.objects.filter(drive=self).aggregate(Sum('size'))['size__sum']
+        # print(f"Free Space: {Partition.objects.filter(drive=self).aggregate(Sum('size'))['size__sum']}")
+        if Partition.objects.filter(drive=self).count() == 0:
+            return self.size
+        else:
+            return self.size - Partition.objects.filter(drive=self).aggregate(Sum('size'))['size__sum']
 
     def device_name(self):
         return f'/dev/sd{chr(ord("`") + int(self.identifier[-1]))}'
